Coverage report

|  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | ---
File |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
actress / __init__.py |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
actress / task.py |  | 93% | 515 | 36 | 6 |  | 85% | 132 | 18 |  | 91%
Total |  | 93% | 517 | 36 | 6 |  | 85% | 132 | 18 |  | 91%

No items found using the specified filter.